@@ -530,13 +530,10 @@ def inicia_db(path_to_jsontiny='', key_decript=b'', client_server=False, host_se
                 return ServerError('Server cant be initialized!')
             while True:
                 if server_is_running:
-                    #('Vai esperar client')
-                    #('editando', editando)
+                    print('Threads at moment: ', threading.active_count())
                     client, addr = server.accept()
-                    #('aceitou')
                     thread = threading.Thread(target=messagesTreatment, args=[client])
                     thread.start()
-                    #(server_is_running)
                 else:
                     break
             #('server fechado')
